#
# spec file for package qml-box2d
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.6.2

Name:           qml-box2d
Version:        0+git.1713207787.3a85439
Release:        1.2
Summary:        QML Box2D plugin
License:        Zlib
Group:          Development/Libraries/C and C++
URL:            https://github.com/%{name}/%{name}
Source:         %{name}-%{version}.tar.xz
%if 0%{?suse_version} < 1599
BuildRequires:  gcc13
BuildRequires:  gcc13-c++
%endif
BuildRequires:  libbox2d-devel
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}

%description
This plugin is meant to be installed to your Qt/imports directory, or shipped
in a directory of which the parent is added as import path.

The goal is to expose the functionality of Box2D as QML components, in order
to make it easy to write physics-based games in QML.

%prep
%setup -q

%build
%if 0%{?suse_version} < 1599
export CC="/usr/bin/gcc-13"
export CXX="/usr/bin/g++-13"
%endif
%cmake
%cmake_build

%install
%cmake_install

rm -rf "%{buildroot}%{_libdir}/qt6/tests"

%files
%license COPYING
%doc README.md
%{_libdir}/Box2D
%{_libdir}/Box2D/qmldir
%{_libdir}/Box2D/libqmlbox2d.so

%changelog
* Sat Feb 22 2025 Bruno Friedmann <bruno@ioda-net.ch>
- lower needed qt6 version to 6.6.2 (available in 15.6)
  gcompris-qt 25 can also be build with 6.6.0
- add if block for leap to use gcc-13 at minimal (avoid include
  filesystem.h not found trouble)
* Mon Feb 17 2025 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 0+git.1713207787.3a85439:
  * cmake, add Qt policy for Qt6 > 6.5 (#147)
  * Fix crash on revoluteplotangle example (#141)
  * Add Windows/MacOS CI builds (#137)
  * README, update to use cmake for building too instead of make (#139)
  * add cmake support (#136)
  * silence some warnings (#135)
  * README.md formatting improvements
  * Support Qt 6 (#131)
  * Removed message when using system Box2D
  * Changed option to use system box2d to use CONFIG instead of DEFINES,
    as this is the more common way to configure qmake projects.
  * Updated debian packaging to use system box2d and depend on it.
  * Updated README to match the changes.
- Packaging
  * refresh copyright
  * migrate to qt6
* Mon Feb 22 2021 bruno@ioda-net.ch
- Update to version 0+git.1523004651.b7212d5:
  * debian: select qt5
  * debian: follow debian qml-module naming sheme
  * debian: standards-version 4.1.3 and compat 11
  * Rename README to README.md Markdown syntax only works well with .md file ending.
  * Improved readme to help beginners. Added a few screenshots of example scenes.
  * Added new example revolutePlotAngle. Plots the revolute joint angle in a nice plot (ChartView)
  * Fixed 'make install' command issue on Android (#119)
  * Added new example angleTracking. Showcases a revolute joint tracking an angle set by mouse clicks.
  * Removed invalid iCCP chunk from PNG files
  * Improved the application showcase file (ui.qml):
  - added permanent list view at side
  - removed back button
  - avoid balls get spawned outside of 'brickwall' scene box
  - fixed accept keys for revolute, moving box examples
  - added key text when necessary
  - removed debugDraw for demolition example, as it caused the
    example to crash if clicked from sidebar
- Packaging
  + refresh with spec-cleaner (license macro, copyright year)
  + due incompatible changes use internal Box2D
  + remove external Box2D dependency
* Sun Aug 21 2016 jengelh@inai.de
- Ensure all created directories are owned.
  Set RPM group classification.
* Sun Aug 21 2016 bruno@ioda-net.ch
- Simplify BuildRequires list with the use of pkgconfig(Qt5Quick)
  This fix the unresolvable qtquick 1 failure on TW
* Sun Jul  3 2016 bruno@ioda-net.ch
- Update to version 0+git.1451747535.1b37be7:
  * Corrected some filenames in header comments
- Don't use github url for src, we use service for that.
* Sun Dec 27 2015 bruno@ioda-net.ch
- First packaging for openSUSE
- Make qml-box2d find system Box2D
